@@ -8,16 +8,24 @@ from touchstone import init
 from touchstone import run
 from touchstone.lib import exceptions
 
+should_log_services: bool = False
+
 
 @click.group()
 @click.option('--log', default='WARNING', help='Sets the log level.')
-def cli(log):
+@click.option('--log-services', is_flag=True, help="Captures service logs and stores them in 'touchstone/logs'.")
+def cli(log, log_services):
+    # Logging
     numeric_level = getattr(logging, log.upper(), None)
     if not isinstance(numeric_level, int):
         raise exceptions.TouchstoneException(f'Invalid log level: {log}')
     logging.basicConfig()
     common.logger.setLevel(numeric_level)
 
+    # Log Services
+    global should_log_services
+    should_log_services = log_services
+
 
 @cli.command('version', help='Prints the Touchstone version number.')
 def cli_version():
@@ -31,12 +39,12 @@ def init_cmd():
 
 @cli.command(name='run', help='Run all Touchstone tests and exit.')
 def run_cmd():
-    run.execute()
+    run.execute(should_log_services)
 
 
 @cli.command(name='develop', help='Start a development session of Touchstone.')
 def develop_cmd():
-    develop.execute()
+    develop.execute(should_log_services)
 
 
 if __name__ == '__main__':
