@@ -6,10 +6,10 @@ from touchstone import common
 from touchstone.bootstrap import Bootstrap
 
 
-def execute():
+def execute(should_log_services=False):
     if not common.sanity_check_passes():
         exit(1)
-    bootstrap = Bootstrap(is_dev_mode=True)
+    bootstrap = Bootstrap(True, should_log_services)
     print(figlet_format('Touchstone', font='larry3d'))
 
     try:
@@ -22,7 +22,7 @@ def execute():
             if command == 'help':
                 __print_help()
             elif command == 'run':
-                bootstrap.mocks.services_became_available()
+                bootstrap.ts_context.trigger_services_available()
                 tests_did_pass = bootstrap.services.run_all_tests()
                 if tests_did_pass:
                     print('All Touchstone tests passed successfully!')
@@ -31,12 +31,13 @@ def execute():
             elif re.search('run \\S* \\S* \\S*', command):
                 command = command.lower()
                 parts = command.split(' ')
-                bootstrap.mocks.services_became_available()
+                bootstrap.ts_context.trigger_services_available()
                 bootstrap.services.run_test(parts[1], parts[2], parts[3])
             elif command == 'services start':
                 try:
-                    bootstrap.services.start(bootstrap.mocks.environment_vars())
-                    bootstrap.mocks.services_became_available()
+                    bootstrap.services.add_environment_vars(bootstrap.mocks.environment_vars())
+                    bootstrap.services.start()
+                    bootstrap.ts_context.trigger_services_available()
                 except KeyboardInterrupt:
                     bootstrap.services.stop()
             elif command == 'services stop':
@@ -62,7 +63,7 @@ def __print_help():
           'help - Prints this message.\n'
           'run - Runs all Touchstone tests.\n'
           'run {service} {test file name} {test name} - Run a single test. Leaves mocks in the tested state.\n'
-          'services start - If you don\'t want to run services manually, this starts all services with a non-empty Dockerfile.\n'
+          'services start - If you don\'t want to run services manually, this starts all networked services with a non-empty Dockerfile.\n'
           'services stop - Stops all started containerized services.\n'
           'mocks print - Prints mock UI URLs.\n'
           'mocks reset - Resets all mocks to their default state.\n'
