@@ -2,8 +2,8 @@ import time
 import traceback
 from typing import List
 
-from touchstone.lib.mocks.mocks import Mocks
-from touchstone.lib.services.i_service_executor import IServiceExecutor
+from touchstone.lib.nodes.mocks.mocks import Mocks
+from touchstone.lib.nodes.services.i_service_executor import IServiceExecutor
 from touchstone.lib.touchstone_test import TouchstoneTest
 
 
